diff lisp/textmodes/org.el @ 64078:ebf5ec3a071e

(org-file-apps-defaults-gnu): Renamed from org-file-apps-defaults-linux. (org-default-apps): Don't test system-type for `linux'. (org-file-apps): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Mon, 04 Jul 2005 14:24:04 +0000
parents dc2198941327
children d5372215b17d
line wrap: on
line diff
--- a/lisp/textmodes/org.el	Mon Jul 04 12:33:21 2005 +0000
+++ b/lisp/textmodes/org.el	Mon Jul 04 14:24:04 2005 +0000
@@ -999,7 +999,7 @@
   :group 'org-link
   :type 'boolean)
 
-(defconst org-file-apps-defaults-linux
+(defconst org-file-apps-defaults-gnu
   '((t        . emacs)
     ("jpg"    . "xv %s")
     ("gif"    . "xv %s")
@@ -1023,7 +1023,7 @@
     ("html"   . "netscape -remote openURL(%s,new-window)")
     ("htm"    . "netscape -remote openURL(%s,new-window)")
     ("xs"     . "soffice %s"))
-  "Default file applications on a UNIX/LINUX system.
+  "Default file applications on a GNU-like system.
 See `org-file-apps'.")
 
 (defconst org-file-apps-defaults-macosx
@@ -1067,7 +1067,7 @@
 For more examples, see the system specific constants
 `org-file-apps-defaults-macosx'
 `org-file-apps-defaults-windowsnt'
-`org-file-apps-defaults-linux'."
+`org-file-apps-defaults-gnu'."
   :group 'org-link
   :type '(repeat
           (cons (string :tag "Extension")
@@ -5388,9 +5388,7 @@
     org-file-apps-defaults-macosx)
    ((eq system-type 'windows-nt)
     org-file-apps-defaults-windowsnt)
-   ((eq system-type 'linux)
-    org-file-apps-defaults-linux)
-   (t org-file-apps-defaults-linux)))
+   (t org-file-apps-defaults-gnu)))
 
 (defun org-expand-file-name (path)
   "Replace special path abbreviations and expand the file name."
@@ -9048,7 +9046,7 @@
 (define-key org-mode-map (org-key 'S-left)  'org-timestamp-down-day)
 (define-key org-mode-map (org-key 'S-right) 'org-timestamp-up-day)
 (define-key org-mode-map "\C-c-"          'org-table-insert-hline)
 ;; The following line is e.g. necessary for German keyboards under Suse Linux
 (unless org-xemacs-p
   (define-key org-mode-map [S-iso-lefttab]  'org-shifttab))
 (define-key org-mode-map [(shift tab)]    'org-shifttab)
@@ -9048,7 +9046,7 @@
 (define-key org-mode-map (org-key 'S-right) 'org-timestamp-up-day)
 (define-key org-mode-map "\C-c-"          'org-table-insert-hline)
-;; The following line is e.g. necessary for German keyboards under Suse Linux
+;; The following line is necessary for German keyboards under Suse GNU/Linux
 (unless org-xemacs-p
   (define-key org-mode-map [S-iso-lefttab]  'org-shifttab))